# Python Actors README

This library was made so you that you can use Python actors to achieve concurrency in your Python code.

If you are unfamiliar with the actor model, here is a quick rundown
* An actor is something capable of accepting a message, and performing work
* An actor can be a parent or a child to another actor
* Actors accept messages that are posted to them
* What an actor does with a message depends on the type of actor


Check out [the docs](https://kmanc.github.io/python_actors/) for more info on how to get started!
